==> 1.2.4.tar.gz: lib/src/entities/map/map_account_data.dart <==
import 'package:rec_api_dart/src/entities/badge.ent.dart';
import 'package:rec_api_dart/src/entities/entity.base.dart';
import 'package:rec_api_dart/src/entities/map/map_campaign_data.dart';

class MapAccountData extends Entity {
  String? name;
  double? latitude;
  double? longitude;
  bool? hasOffers;
  List<MapCampaignData> campaigns;
  List<Badge> badges;

  MapAccountData({
    String? id,
    String? createdAt,
    String? updatedAt,
    this.name,
    this.latitude,
    this.longitude,
    this.hasOffers,
    this.campaigns = const [],
    this.badges = const [],
  }) : super(id, createdAt, updatedAt);

  factory MapAccountData.fromJson(Map<String, dynamic> json) {
    var campaigns = <MapCampaignData>[];
    var badges = <Badge>[];

    if (json['campaigns'] != null) {
      final jsonCampaigns = List.from(json['campaigns']);
      campaigns = jsonCampaigns.isNotEmpty
          ? jsonCampaigns.map<MapCampaignData>((el) => MapCampaignData.fromJson(el)).toList()
          : [];
    }

    if (json['badges'] != null) {
      final jsonBadges = List.from(json['badges']);
      badges = jsonBadges.isNotEmpty
          ? jsonBadges.map<Badge>((el) => Badge.fromJson(el)).toList()
          : <Badge>[];
    }

    return MapAccountData(
      id: '${json['id']}',
      name: json['name'],
      latitude: double.parse((json['latitude'] ?? 0).toString()),
      longitude: double.parse((json['longitude'] ?? 0).toString()),
      hasOffers: json['has_offers'],
      campaigns: campaigns,
      badges: badges,
    );
  }
}

==> 1.2.5.tar.gz: lib/src/entities/map/map_account_data.dart <==
import 'package:rec_api_dart/src/entities/badge.ent.dart';
import 'package:rec_api_dart/src/entities/entity.base.dart';
import 'package:rec_api_dart/src/entities/map/map_campaign_data.dart';

class MapAccountData extends Entity {
  String? name;
  double? latitude;
  double? longitude;
  bool? hasOffers;
  bool? isComercVerd;
  List<MapCampaignData> campaigns;
  List<Badge> badges;

  MapAccountData({
    String? id,
    String? createdAt,
    String? updatedAt,
    this.name,
    this.latitude,
    this.longitude,
    this.hasOffers,
    this.isComercVerd,
    this.campaigns = const [],
    this.badges = const [],
  }) : super(id, createdAt, updatedAt);

  factory MapAccountData.fromJson(Map<String, dynamic> json) {
    var campaigns = <MapCampaignData>[];
    var badges = <Badge>[];

    if (json['campaigns'] != null) {
      final jsonCampaigns = List.from(json['campaigns']);
      campaigns = jsonCampaigns.isNotEmpty
          ? jsonCampaigns.map<MapCampaignData>((el) => MapCampaignData.fromJson(el)).toList()
          : [];
    }

    if (json['badges'] != null) {
      final jsonBadges = List.from(json['badges']);
      badges = jsonBadges.isNotEmpty
          ? jsonBadges.map<Badge>((el) => Badge.fromJson(el)).toList()
          : <Badge>[];
    }

    return MapAccountData(
      id: '${json['id']}',
      name: json['name'],
      latitude: double.parse((json['latitude'] ?? 0).toString()),
      longitude: double.parse((json['longitude'] ?? 0).toString()),
      hasOffers: json['has_offers'] ?? false,
      isComercVerd: json['is_comerc_verd'] ?? false,
      campaigns: campaigns,
      badges: badges,
    );
  }
}
